@@ -111,7 +111,7 @@ public class ClassFile implements Cloneable {
    * @param fields fields this class will have
    */
   public ClassFile(int modifiers,String name,Class<?> superClass,
-                   Class[] interfaces,LocalField[] fields) {
+                   Class<?>[] interfaces,LocalField[] fields) {
     
     constPoolData=new ByteArrayOutputStream();
     constPool=new DataOutputStream(constPoolData);
@@ -241,7 +241,7 @@ public class ClassFile implements Cloneable {
    * @param m method descriptor.
    * @param vars types of local variables by number.
    */
-  public void newMethod(LocalMethod m, Class[] vars) {
+  public void newMethod(LocalMethod m, Class<?>[] vars) {
 
     if (Debug.enabled) {
       Debug.check(cW==0);
@@ -265,7 +265,7 @@ public class ClassFile implements Cloneable {
     writeShort(getUTFIndex(Library.getSignature(m))); // signature index
     
     int temp=0;
-    Class[] exceptions=m.getExceptionTypes();
+    Class<?>[] exceptions=m.getExceptionTypes();
     if (exceptions!=null) temp++; // exceptions are in separate attribute
     if (!isAbstract) temp++; // non-abstract methods have code
     writeShort(temp);
@@ -292,7 +292,7 @@ public class ClassFile implements Cloneable {
       writeShort(0);     // max stack, to be patched back
       
       // local variables
-      Class[] params=m.getParameterTypes();
+      Class<?>[] params=m.getParameterTypes();
       int parlen=(params==null?0:params.length);
       int varlen=(vars==null?0:vars.length);
       int this_num=(mdfrs & 0x0008)==0?1:0; // if not static there is "this"
@@ -422,7 +422,7 @@ public class ClassFile implements Cloneable {
   /**
    * classes frequently used in generated code
    */
-  private static final Class[] specialClasses;
+  private static final Class<?>[] specialClasses;
 
   static {
     if (Debug.enabled)
@@ -749,6 +749,7 @@ public class ClassFile implements Cloneable {
     if (Debug.enabled)  
       Debug.check(((primitiveID>=0) && (primitiveID<8)) || 
                    ((primitiveID==8) && (o==null)) || 
+                   ((primitiveID==11) && (o==null)) ||
                    ((primitiveID==10) && (o instanceof StringBuffer)) ||
                    ((primitiveID==11) && (o instanceof String)));
     int short_opcodes=0;
@@ -794,7 +795,10 @@ public class ClassFile implements Cloneable {
     case 10:
       tsb_store=true;
     case 11:
-      short_opcodes=0;
+      if (o==null)
+        short_opcodes=0x01;      //| aconst_null
+      else
+        short_opcodes=0;
       primitiveID=8;
       break;
     default:
@@ -860,7 +864,7 @@ public class ClassFile implements Cloneable {
     // Check if it is in the pool already
     Integer index=UTFs.get(str);
     if (index==null) {    // add UTF to the pool
-      index=new Integer(poolEntries++);
+      index=Integer.valueOf(poolEntries++);
       try {
         constPool.write(1);            // CONSTANT_Utf8 = 1;
         constPool.writeUTF(str);
@@ -979,7 +983,7 @@ public class ClassFile implements Cloneable {
       } catch (java.io.IOException e) {
         if (Debug.enabled) Debug.reportThrowable(e);
       };
-      index=new Integer(newIndex);
+      index=Integer.valueOf(newIndex);
       Items.put(item,index);
     };
     return index.intValue();
