@@ -67,13 +67,13 @@ public class OPbinary extends OP {
    * 7   --  bitwise and logical XOR
    * 8   --  comparizon for equality
    * 9   --  comparizon for non-equality
-   * 10  --  comparizon for "less" <
-   * 11  --  comparizon for "greater or equal" >=
-   * 12  --  comparizon for "greater" >
-   * 13  --  comparizon for "less or equal" <=
-   * 14  --  bitwise left shift <<
-   * 15  --  bitwise right signed shift >>
-   * 16  --  bitwise right unsigned shift >>>
+   * 10  --  comparizon for "less" &lt;
+   * 11  --  comparizon for "greater or equal" &gt;=
+   * 12  --  comparizon for "greater" &gt;
+   * 13  --  comparizon for "less or equal" &lt;=
+   * 14  --  bitwise left shift &lt;&lt;
+   * 15  --  bitwise right signed shift &gt;&gt;
+   * 16  --  bitwise right unsigned shift &gt;&gt;&gt;
    * 17  --  logical conjunction operator (AND)
    * 18  --  logical disjunction operator (OR)
    * 19  --  array element access operation
@@ -284,9 +284,9 @@ public class OPbinary extends OP {
           if (Debug.enabled && wrop)
             Debug.println("Wrong operation on float ("+code+").");      
         
-          if (!boolres) n1=new Double(d1);
+          if (!boolres) n1=Double.valueOf(d1);
           else { // booleans are represented by longs temporarily
-            if (resbool) n1=new Long(1L); else n1=new Long(0);
+            if (resbool) n1=Long.valueOf(1L); else n1=Long.valueOf(0);
           };
         } else { // operations on integers
           long l1=n1.longValue(),l2=n2.longValue();
@@ -321,7 +321,7 @@ public class OPbinary extends OP {
             if (Debug.enabled)
               Debug.println("Wrong operation on integer ("+code+").");      
           };
-          n1=new Long(l1);
+          n1=Long.valueOf(l1);
         };
       
         // Narrow    
