@@ -249,7 +249,7 @@ public class OPcall extends OP {
           Class<?>[] reqParamTypes=Library.getParameterTypes(m,-1);
           LA=reqParamTypes[reqParamTypes.length - 1].getComponentType();
           tID=typeID(LA);
-          cf.codeLDC(new Integer(va),4);       // push item count to the stack
+          cf.codeLDC(Integer.valueOf(va),4);       // push item count to the stack
           if (tID<8) {
             // array of primitive types
             cf.code(0xbc);                     // |    newarray
@@ -264,7 +264,7 @@ public class OPcall extends OP {
         if (i>=chi.length-va) {
           cf.code(0x59);                       // |    dup
           cf.noteStk(-1, 8);    // another array ref comes in
-          cf.codeLDC(new Integer(i-chi.length+va),4); // load array index         
+          cf.codeLDC(Integer.valueOf(i-chi.length+va),4); // load array index         
         }
         chi[i].compile(cf);  // compile the argument value
         cf.code(0xFA);       // ensure value in stack 
