@@ -65,6 +65,10 @@ public class OPload extends OP {
             (
              (instead.resID==10) && 
              (what instanceof StringBuffer)
+             ) ||
+            (
+             (typeIDObject(what)==8) &&
+             (what==null)
              )
             )
           ) {
@@ -82,6 +86,10 @@ public class OPload extends OP {
                    (
                     (instead.resID==10) && 
                     (what instanceof StringBuffer)
+                    ) ||
+                   (
+                    (typeIDObject(what)==8) &&
+                    (what==null)
                     )
                    );
     };
