@@ -192,16 +192,18 @@ public class Parser {
     return c;
   };
 
+  public void error(int code, Object param, int column) 
+    throws CompilationException {
+    CompilationException exc = new CompilationException(code,param);
+    exc.col=column;
+    throw exc;
+  }
+
   // because EOF can never be expected, "consume(-1)" has a special
   // meaning, which is just to report the "current unexpected" char.
   protected void consume(int cc) throws CompilationException {
-    if ((cc<0) || (c!=cc)) {
-      CompilationException exc=
-        new CompilationException(c==-1?1:3,new Character((char)c));
-      exc.col=column;
-      if (c==-1) exc.col--;
-      throw exc;
-    };
+    if ((cc<0) || (c!=cc))
+      error(c==-1?1:3,Character.valueOf((char)c),column-(c==-1?1:0));
     read();
   };
 
@@ -406,7 +408,7 @@ public class Parser {
     consume('\'');
     
     type=60; // <LITERAL>
-    val=new Character(ch);
+    val=Character.valueOf(ch);
     return;
   };
 
@@ -489,19 +491,19 @@ public class Parser {
         if (base==10) {
           // check for overflow, e.g. when can't store any more decimal digits
           if ((value*10)/10 != value) 
-            consume(-1); // overflow (make better overflow reporting)
+            error(30,null,column-1); // overflow
           value=value*10+(c-'0');
         } else if (base==8) {
           // check for overflow, e.g. when can't store any more octal digits
           // e.g. highest three bits already occupied
           if ((value>>>61)>0)
-            consume(-1); // overflow (make better overflow reporting)
+            error(30,null,column-1); // overflow
           value=(value<<3)+(c-'0');
         } else { // hexadecimal number
           // check for overflow, e.g. when can't store any more hex digits
           // e.g. highest four bits already occupied
           if ((value>>>60)>0)
-            consume(-1); // overflow (make better overflow reporting)
+            error(30,null,column-1); // overflow
           value=(value<<4)+(c-'0');
         };
         break;
@@ -518,7 +520,7 @@ public class Parser {
         // check for overflow, e.g. when can't store any more hex digits
         // e.g. highest four bits already occupied
         if ((value>>>60)>0)
-          consume(-1);  // overflow (make better overflow reporting)
+          error(30,null,column-1); // overflow
         value=(value<<4)+(10+Character.toLowerCase((char)c)-'a');
         break;
       case '.':
@@ -532,7 +534,7 @@ public class Parser {
         read();
         buf.setLength(0); // discard accumulated chars
         type=60; // <LITERAL>
-        val=new Long(value);
+        val=Long.valueOf(value);
         break outerLoop; // finished parsing 'long' <LITERAL>
       case 'X': case 'x':
         if ((buf.length()==1) && (base==8)) {
@@ -551,13 +553,13 @@ public class Parser {
         // select type based on range
         // note that the minus sign is handled as unary OP, not
         // as part of the number
-        if (value<=127) val=new Byte((byte)value);
-        else if (value<=32767) val=new Short((short)value);
-        else if (value<=2147483647) val=new Integer((int)value);
+        if (value<=127) val=Byte.valueOf((byte)value);
+        else if (value<=32767) val=Short.valueOf((short)value);
+        else if (value<=2147483647) val=Integer.valueOf((int)value);
         else if (((base==16) || (base==8)) &&
                  (value<=4294967295L)) // we allow HEX and octal ints
-          val=new Integer((int)value); // to overflow to negative values
-        else consume(-1); // overflow (make better overflow reporting)
+          val=Integer.valueOf((int)value); // to overflow to negative values
+        else error(29,Long.valueOf(value),column-1); // int overflow
         break outerLoop;
       };
     };
@@ -632,12 +634,12 @@ public class Parser {
         if (makeFloat) {
           val=Float.valueOf(buf.toString());
           if (Float.isInfinite(((Float)val).floatValue()))
-            consume(-1); // overflow (make better overflow reporting)
+            error(31,null,column-1); // floating point literal overflow
         } else {
           // makeDouble
           val=Double.valueOf(buf.toString());
           if (Double.isInfinite(((Double)val).doubleValue()))
-            consume(-1); // overflow (make better overflow reporting)
+            error(31,null,column-1); // floating point literal overflow
         };
         buf.setLength(0); // if success -- reset buf
       };
@@ -752,7 +754,7 @@ public class Parser {
    * @param resultType the type to convert the result into
    * @return top of the parse tree
    */
-  public OP parse(Class resultType) throws CompilationException {
+  public OP parse(Class<?> resultType) throws CompilationException {
     try {
       expression();
 
@@ -911,7 +913,7 @@ public class Parser {
       
       // generate convert OP
       int typeID=0;
-      Class clazz=null;
+      Class<?> clazz=null;
       while ((typeID<8) &&
              !typeAccum.substring(accumStrt).
              equals(OP.specialTypes[typeID].toString()))
@@ -986,7 +988,7 @@ public class Parser {
 
   private void invocation(boolean afterDot) throws CompilationException {
     int paramsStart=0;
-    Class resolveIn=null;
+    Class<?> resolveIn=null;
     int ecol,ecol_id;
     boolean inDVmatch=false;
 
@@ -998,7 +1000,14 @@ public class Parser {
       int oldLen=accDV.length();
       if (afterDot) accDV.append('.');
       accDV.append(idImage);
-      if (!(inDVmatch=isDV())) {
+      if (!(inDVmatch=(isDV()&&(type!=41)))) {
+        // The condition above means: if the whole accumulated name (what was
+        // in accDV before plus the last ID) is a valid DV name and also the
+        // next token is not a beginning of the formal parameters list,
+        // then we are content with adding the ID to the accDV.
+        // Otherwise we go back up, loading the previously successfully
+        // accumulated DV name and resolve the last ID as a method call
+        // (or a field loading on an object).
         accDV.setLength(oldLen); // back up
         err_col=ecol;
         genDVCall(); // finish prepared DV call
@@ -1014,16 +1023,6 @@ public class Parser {
     if (type==41) { // '('
       ecol=ct_column; // error will be reported against this '('
 
-      
-      if (inDVmatch) {
-        // error: variable must have no parameters
-        err_col=ecol;
-        {if (true) throw new CompilationException(26,null);}
-
-        // this is the place to hack in the abort of match and check
-        // if the last matched name can be called as a method
-      };
-
       nextToken();
 
       // now we need to determine if conditional() is present
@@ -1095,11 +1094,11 @@ public class Parser {
   }
 
   
-  private final void functionCall(Class resolveInClass,String name,
+  private final void functionCall(Class<?> resolveInClass,String name,
                                   int paramsStart) throws CompilationException{
     // collect params
     int np=paramOPs.size()-paramsStart;
-    Class[] params=new Class[np];
+    Class<?>[] params=new Class<?>[np];
 
     for(int i=np-1;i>=0;i--) {
       OP cop=paramOPs.pop();
@@ -1116,7 +1115,7 @@ public class Parser {
         // insert loading of "this" pointer
         paramOPs.push(new OPcall(1,(new Object[0]).getClass()));
         int classID=lib.getDynamicMethodClassID(m);
-        paramOPs.push(new OPload(new Integer(classID)));
+        paramOPs.push(new OPload(Integer.valueOf(classID)));
         paramOPs.push(new OPbinary(paramOPs,19));
       }
     }
@@ -1125,7 +1124,7 @@ public class Parser {
     for(int i=0;i<np;i++)
       paramOPs.push(xchgOP.pop());
 
-    paramOPs.push(new OPcall(paramOPs,m,lib.isStateless(m)));
+    paramOPs.push(new OPcall(m, np, paramOPs, lib.isStateless(m)));
   }
 
   //*** PARSER methods
