@@ -170,14 +170,14 @@ public class TableWriter {
           {27,10},             // java.lang.Double.doubleValue()       | 26
           {11,11,30},          // String.valueOf(Object)               | 27 // unwraps String-like
           {31,12,11,11},       // CompiledExpression.compare(String,String) | 28 // compares two strings
-          {20+100,0,0},        // java.lang.Boolean(boolean)           | 29
-          {21+100,0,1},        // java.lang.Byte(byte)                 | 30
-          {22+100,0,2},        // java.lang.Character(char)            | 31
-          {23+100,0,3},        // java.lang.Short(short)               | 32
-          {24+100,0,4},        // java.lang.Integer(int)               | 33
-          {25+100,0,5},        // java.lang.Long(long)                 | 34
-          {26+100,0,6},        // java.lang.Float(float)               | 35
-          {27+100,0,7},        // java.lang.Double(double)             | 36
+          {20,11,0},           // java.lang.Boolean.valueOf(boolean)   | 29
+          {21,11,1},           // java.lang.Byte.valueOf(byte)         | 30
+          {22,11,2},           // java.lang.Character.valueOf(char)    | 31
+          {23,11,3},           // java.lang.Short.valueOf(short)       | 32
+          {24,11,4},           // java.lang.Integer.valueOf(int)       | 33
+          {25,11,5},           // java.lang.Long.valueOf(long)         | 34
+          {26,11,6},           // java.lang.Float.valueOf(float)       | 35
+          {27,11,7},           // java.lang.Double.valueOf(double)     | 36
         };
         tables.put("specialMds",specialMds);
 
