@@ -45,14 +45,14 @@ public class ClassFileExprTest extends TestCase {
     lf[0]=new LocalField(0x0002,(new Object[0]).getClass(),"e",null);
     //	cf = new ClassFile(0x0001,"dump",(new Object()).getClass(),null,lf);
     
-    Class[] stat=new Class<?>[1];
+    Class<?>[] stat=new Class<?>[1];
     stat[0]=Class.forName("java.lang.Math");
-    Class[] dyn=new Class<?>[1];
+    Class<?>[] dyn=new Class<?>[1];
     dyn[0]=Class.forName("java.lang.Double");
     lib=new Library(stat,dyn,null,null,null);
     
     dynalib=new Object[1];
-    dynalib[0]=new Double(100.0);
+    dynalib[0]=Double.valueOf(100.0);
     
     image=null;
     final int numPrimitives=10;  // up to Void
@@ -61,7 +61,7 @@ public class ClassFileExprTest extends TestCase {
     retID_patchback=0;
 
     // prepare eval methods
-    Class[] paramsE=new Class<?>[1];
+    Class<?>[] paramsE=new Class<?>[1];
     paramsE[0]=(new Object[0]).getClass();
     for(int i=0;i<numPrimitives-1;i++) {
       String name="evaluate";
@@ -115,23 +115,23 @@ public class ClassFileExprTest extends TestCase {
 
   public void testExecTemplate() throws Throwable {
     CompiledExpression expr= 
-      (CompiledExpression)(ImageLoader.load(image)).newInstance();
+      (CompiledExpression)(ImageLoader.load(image)).getDeclaredConstructor().newInstance();
       boolean ok=((expr.getType()==8) && (expr.evaluate(null)==null));
     assertTrue(ok);
   }
 
   public void testExpr1() throws Throwable {
-    exprMiniComp("1 (I)",dynalib,lib,new Integer(1),
+    exprMiniComp("1 (I)",dynalib,lib,Integer.valueOf(1),
              cf_orig,retID_patchback,eval_methods,false);
   };
 
   public void testExpr2() throws Throwable {
-    exprMiniComp("1 (I)",dynalib,lib,new Integer(1),
+    exprMiniComp("1 (I)",dynalib,lib,Integer.valueOf(1),
              cf_orig,retID_patchback,eval_methods,false);
   };
 
   public void testExpr3() throws Throwable {
-    exprMiniComp("1 -- (I)",dynalib,lib,new Integer(-1),
+    exprMiniComp("1 -- (I)",dynalib,lib,Integer.valueOf(-1),
              cf_orig,retID_patchback,eval_methods,false);
   };
 
@@ -140,29 +140,29 @@ public class ClassFileExprTest extends TestCase {
   // and floating point constants
 
   public void testExpr4() throws Throwable {
-    exprMiniComp("1 --",dynalib,lib,new Integer((byte)-1),
+    exprMiniComp("1 --",dynalib,lib,Integer.valueOf((byte)-1),
                  cf_orig,retID_patchback,eval_methods,false);
   };
   
   public void testExpr5() throws Throwable {
-    exprMiniComp("1L --",dynalib,lib,new Long(-1),
+    exprMiniComp("1L --",dynalib,lib,Long.valueOf(-1),
                  cf_orig,retID_patchback,eval_methods,false);
   };
 
   public void testExpr6() throws Throwable {
     for(byte i=0;i<=6;i++) {
-      exprMiniComp(String.valueOf(i),dynalib,lib,new Byte(i),
+      exprMiniComp(String.valueOf(i),dynalib,lib,Byte.valueOf(i),
                    cf_orig,retID_patchback,eval_methods,false);
-      exprMiniComp(String.valueOf(i)+'L',dynalib,lib,new Long(i),
+      exprMiniComp(String.valueOf(i)+'L',dynalib,lib,Long.valueOf(i),
                    cf_orig,retID_patchback,eval_methods,false);
     };
   };
   
   public void testExpr7() throws Throwable {
     for(byte i=0;i<=3;i++) {
-      exprMiniComp(String.valueOf(i)+".0F",dynalib,lib,new Float(i),
+      exprMiniComp(String.valueOf(i)+".0F",dynalib,lib,Float.valueOf(i),
                    cf_orig,retID_patchback,eval_methods,false);
-      exprMiniComp(String.valueOf(i)+".0",dynalib,lib,new Double(i),
+      exprMiniComp(String.valueOf(i)+".0",dynalib,lib,Double.valueOf(i),
                    cf_orig,retID_patchback,eval_methods,false);
     };
   };
@@ -182,36 +182,36 @@ public class ClassFileExprTest extends TestCase {
   // and loading through the CP.
   public void testExpr10() throws Throwable {
     for(int i=126;i<=128;i++) {
-      exprMiniComp(String.valueOf(i)+" (I)",dynalib,lib,new Integer(i),
+      exprMiniComp(String.valueOf(i)+" (I)",dynalib,lib,Integer.valueOf(i),
                    cf_orig,retID_patchback,eval_methods,false);
-      exprMiniComp(String.valueOf(i)+" -- (I)",dynalib,lib,new Integer(-i),
+      exprMiniComp(String.valueOf(i)+" -- (I)",dynalib,lib,Integer.valueOf(-i),
                    cf_orig,retID_patchback,eval_methods,false);
     };
   };
 
   public void testExpr11() throws Throwable {
-    exprMiniComp("( 1 , 2 , min)",dynalib,lib,new Integer(1),
+    exprMiniComp("( 1 , 2 , min)",dynalib,lib,Integer.valueOf(1),
                  cf_orig,retID_patchback,eval_methods,false);
   };
 
   public void testExpr12() throws Throwable {
-    exprMiniComp("( ( E) , sin)",dynalib,lib,new Double(Math.sin(Math.E)),
+    exprMiniComp("( ( E) , sin)",dynalib,lib,Double.valueOf(Math.sin(Math.E)),
                  cf_orig,retID_patchback,eval_methods,false);
   };
 
   public void testExpr13() throws Throwable {
-    exprMiniComp("2 , 2 , *",dynalib,lib,new Integer(4),
+    exprMiniComp("2 , 2 , *",dynalib,lib,Integer.valueOf(4),
                  cf_orig,retID_patchback,eval_methods,false);
   };
 
   public void testExpr14() throws Throwable {
-    exprMiniComp("3 , 2 , * , 1 , -",dynalib,lib,new Integer(5),
+    exprMiniComp("3 , 2 , * , 1 , -",dynalib,lib,Integer.valueOf(5),
                  cf_orig,retID_patchback,eval_methods,false);
   };
 
   public void testExpr15() throws Throwable {
     exprMiniComp("3 , 2 , * , 1 , - , 3 , - , 2 , *",dynalib,lib,
-                 new Integer(4),
+                 Integer.valueOf(4),
                  cf_orig,retID_patchback,eval_methods,false);
   };
 
@@ -247,25 +247,25 @@ public class ClassFileExprTest extends TestCase {
 
   public void testExpr21() throws Throwable {
     exprMiniComp("( true ? 1 : 2 ) (I)",dynalib,lib,
-                 new Integer(1),
+                 Integer.valueOf(1),
                  cf_orig,retID_patchback,eval_methods,false);
   };
 
   public void testExpr22() throws Throwable {
     exprMiniComp("( false ? 1 : 2 ) (I)",dynalib,lib,
-                 new Integer(2),
+                 Integer.valueOf(2),
                  cf_orig,retID_patchback,eval_methods,false);
   };
   
   public void testExpr23() throws Throwable {
     exprMiniComp("( false ? 1 : 2 , 2 , + ) (I)",dynalib,lib,
-                 new Integer(4),
+                 Integer.valueOf(4),
                  cf_orig,retID_patchback,eval_methods,false);
   };
 
   public void testExpr24() throws Throwable {
     exprMiniComp("( true ? ( 1 , 3 , + , 5 , min) : 2 ) (I)",dynalib,lib,
-                 new Integer(4),
+                 Integer.valueOf(4),
                  cf_orig,retID_patchback,eval_methods,false);
   };
 
@@ -437,7 +437,7 @@ public class ClassFileExprTest extends TestCase {
               };
               Double value=null;
               try {
-                value=new Double(svalue);
+                value=Double.valueOf(svalue);
               } catch (NumberFormatException e) {
                 System.err.println("Can;t parse \""+svalue+
                                    "\" as a floating point number.");
@@ -447,7 +447,7 @@ public class ClassFileExprTest extends TestCase {
               Class<?> otlc=null;
                 
               if (makeFloat) {
-                otl=new Float(value.floatValue());
+                otl=Float.valueOf(value.floatValue());
                 otlc=Float.TYPE;
               } else {
                 otl=value;
@@ -482,20 +482,20 @@ public class ClassFileExprTest extends TestCase {
               Class<?> otlc=null;
               if (!makelong) { // Check ranges
                 if (value<=127) {
-                  otl=new Byte((byte)value);
+                  otl=Byte.valueOf((byte)value);
                   otlc=Byte.TYPE;
                 } else if (value<=32767) {
-                  otl=new Short((short)value);
+                  otl=Short.valueOf((short)value);
                   otlc=Short.TYPE;
                 } else if (value<=2147483647) {
-                  otl=new Integer((int)value);
+                  otl=Integer.valueOf((int)value);
                   otlc=Integer.TYPE;
                 } else
                   System.err.println("Integer number \""+svalue+
                                      "\" is too large for type 'int'. Be sure"+
                                      " to add 'L' suffix to use 'long' type.");
               } else {
-                otl=new Long(value);
+                otl=Long.valueOf(value);
                 otlc=Long.TYPE;
               };
               paramOPs.push(new OPload(otl));
@@ -527,7 +527,7 @@ public class ClassFileExprTest extends TestCase {
               };
               chr=ec;
             };
-            paramOPs.push(new OPload(new Character(chr)));
+            paramOPs.push(new OPload(Character.valueOf(chr)));
           };
           break;
         case '"':
@@ -577,7 +577,7 @@ public class ClassFileExprTest extends TestCase {
               int ps=paramsStart.pop();
               int np=paramOPs.size()-ps;
 
-              Class[] params=new Class<?>[np];
+              Class<?>[] params=new Class<?>[np];
               OP[] paramsOPs=new OP[np];
               for(int i=np-1;i>=0;i--) {
                 paramsOPs[i]=paramOPs.pop();
@@ -598,7 +598,7 @@ public class ClassFileExprTest extends TestCase {
                 paramOPs.push(new OPcall(1,
                                          (new Object[0]).getClass()));
                 int classID=lib.getDynamicMethodClassID(m);
-                paramOPs.push(new OPload(new Integer(classID)));
+                paramOPs.push(new OPload(Integer.valueOf(classID)));
                 paramOPs.push(new OPbinary(paramOPs,19));
               };
                 
@@ -658,7 +658,7 @@ public class ClassFileExprTest extends TestCase {
         
       // load & execute
       CompiledExpression cexpr= 
-        (CompiledExpression)(ImageLoader.load(image)).newInstance();
+        (CompiledExpression)(ImageLoader.load(image)).getDeclaredConstructor().newInstance();
         
       Object res=cexpr.evaluate(thisPtrs);
         
