@@ -34,10 +34,10 @@ public class IntegralDotOperatorTest extends TestingUtils {
   VariableProvider vp;
 
   public void setUp() throws Exception {
-    Class[] dynamicLib=new Class<?>[1];
+    Class<?>[] dynamicLib=new Class<?>[1];
     rtp=new Object[1];
     vp=new VariableProvider();
-    Class[] staticLib=new Class<?>[2];
+    Class<?>[] staticLib=new Class<?>[2];
     staticLib[0]=Class.forName("java.lang.Math");
     // next line makes also static functions from VariablePrivider available
     staticLib[1]=vp.getClass();  
@@ -46,7 +46,7 @@ public class IntegralDotOperatorTest extends TestingUtils {
     rtp[0]=vp;
     dynamicLib[0]=vp.getClass();
 
-    Class[] dotLib=new Class<?>[5];
+    Class<?>[] dotLib=new Class<?>[5];
     dotLib[0]=Class.forName("java.lang.String");
     dotLib[1]=Class.forName("java.lang.Double");
     dotLib[2]=Class.forName("gnu.jel.reflect.Double");
@@ -57,15 +57,15 @@ public class IntegralDotOperatorTest extends TestingUtils {
   
   
   public void test1() throws Throwable {
-    simExpression("(\"abc\").length()", new Integer(3), null, rtp, lib,null);
+    simExpression("(\"abc\").length()", Integer.valueOf(3), null, rtp, lib,null);
   }
 
   public void test2() throws Throwable {
-    simExpression("\"abc\".length()", new Integer(3), null, rtp, lib,null);
+    simExpression("\"abc\".length()", Integer.valueOf(3), null, rtp, lib,null);
   }
 
   public void test3() throws Throwable {
-    simExpression("strVar.length()", new Integer(6), null, rtp, lib,null);
+    simExpression("strVar.length()", Integer.valueOf(6), null, rtp, lib,null);
   }
 
   public void test4() throws Throwable {
@@ -73,15 +73,15 @@ public class IntegralDotOperatorTest extends TestingUtils {
   }
 
   public void test5() throws Throwable {
-    simExpression("\"abc\".compareTo(\"bc\")", new Integer(-1), null, rtp, lib,null);
+    simExpression("\"abc\".compareTo(\"bc\")", Integer.valueOf(-1), null, rtp, lib,null);
   }
 
   public void test6() throws Throwable {
-    simExpression("\"abcdbc\".indexOf(\"bc\")", new Integer(1), null, rtp, lib,null);
+    simExpression("\"abcdbc\".indexOf(\"bc\")", Integer.valueOf(1), null, rtp, lib,null);
   }
 
   public void test7() throws Throwable {
-    simExpression("\"abcdbc\".indexOf(\"abc\".substring(1),2)", new Integer(4), null, rtp, lib,null);
+    simExpression("\"abcdbc\".indexOf(\"abc\".substring(1),2)", Integer.valueOf(4), null, rtp, lib,null);
   }
 
   public void test8() throws Throwable {
@@ -97,37 +97,37 @@ public class IntegralDotOperatorTest extends TestingUtils {
   }
 
   public void test11() throws Throwable {
-    simExpression("intObj+1", new Integer(556), null, rtp, lib,null);
+    simExpression("intObj+1", Integer.valueOf(556), null, rtp, lib,null);
   }
 
   public void test12() throws Throwable {
-    simExpression("(int)intObj", new Integer(555), null, rtp, lib,null);
+    simExpression("(int)intObj", Integer.valueOf(555), null, rtp, lib,null);
   }
 
   public void test13() throws Throwable {
-    simExpression("arr[intObj-554]", new Double(5.0), null, rtp, lib,null);
+    simExpression("arr[intObj-554]", Double.valueOf(5.0), null, rtp, lib,null);
   }
 
   public void test14() throws Throwable {
-    simExpression("arr[max(intObj-554,0)]", new Double(5.0), null, rtp, lib,null);
+    simExpression("arr[max(intObj-554,0)]", Double.valueOf(5.0), null, rtp, lib,null);
   }
 
   public void test15() throws Throwable {
-    simExpression("arr[max(intObj,0)-554]", new Double(5.0), null, rtp, lib,null);
+    simExpression("arr[max(intObj,0)-554]", Double.valueOf(5.0), null, rtp, lib,null);
   }
 
   public void test16() throws Throwable {
-    simExpression("arr[byteObj]", new Double(6.0), null, rtp, lib,null);
+    simExpression("arr[byteObj]", Double.valueOf(6.0), null, rtp, lib,null);
   }
 
   public void test17() throws Throwable {
-    simExpression("byteObj+1.0", new Double(3.0), null, rtp, lib,null);
+    simExpression("byteObj+1.0", Double.valueOf(3.0), null, rtp, lib,null);
   }
 
   public void test18() throws Throwable {
     simExpression("arrDoubleJELObj1[0].getValue()+"+
                    "arrDoubleJELObj1[1].getValue()",
-                   new Double(3.0), null, rtp, lib,null);
+                   Double.valueOf(3.0), null, rtp, lib,null);
   }
   
 };
