@@ -1,14 +1,22 @@
 /* -*- Mode: Java; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
- * $Id: TestSuite.java,v 1.47 2004/03/16 15:51:25 metlov Exp $
- *
- * This file is part of the Java Expressions Library (JEL).
- *
- * (c) 1998 -- 2007 by Konstantin L. Metlov
- *
- * JEL is Distributed under the terms of GNU General Public License.
- *    This code comes with ABSOLUTELY NO WARRANTY.
- *  For license details see COPYING file in this directory.
- */
+*   This file is part of the Java Expressions Library (JEL).
+*   For more information about JEL visit : http://fti.dn.ua/JEL/
+*
+*   Copyright (C) 1998, 1999, 2000, 2001, 2003, 2006, 2007, 2009 Konstantin L. Metlov
+*
+*   This program is free software: you can redistribute it and/or modify
+*   it under the terms of the GNU General Public License as published by
+*   the Free Software Foundation, either version 3 of the License, or
+*   (at your option) any later version.
+*
+*   This program is distributed in the hope that it will be useful,
+*   but WITHOUT ANY WARRANTY; without even the implied warranty of
+*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+*   GNU General Public License for more details.
+*
+*   You should have received a copy of the GNU General Public License
+*   along with this program.  If not, see <http://www.gnu.org/licenses/>.
+*/
 
 package gnu.jel;
 
@@ -24,15 +32,15 @@ public class IntegralPrimitiveOPsTest extends TestingUtils {
   Library lib;
   Object[] rtp;
   VariableProvider vp;
-  Class[] staticLib;
-  Class[] dynamicLib;
-  java.util.HashMap<String,Class> allowedCasts;
+  Class<?>[] staticLib;
+  Class<?>[] dynamicLib;
+  java.util.HashMap<String,Class<?>> allowedCasts;
 
   public void setUp() throws Exception {
-    dynamicLib=new Class[1];
+    dynamicLib=new Class<?>[1];
     rtp=new Object[1];
     vp=new VariableProvider();
-    staticLib=new Class[2];
+    staticLib=new Class<?>[2];
     staticLib[0]=Class.forName("java.lang.Math");
     // next line makes also static functions from VariablePrivider available
     staticLib[1]=vp.getClass();  
@@ -41,7 +49,7 @@ public class IntegralPrimitiveOPsTest extends TestingUtils {
     rtp[0]=vp;
     dynamicLib[0]=vp.getClass();
 
-    Class[] dotLib=new Class[5];
+    Class<?>[] dotLib=new Class<?>[5];
     dotLib[0]=Class.forName("java.lang.String");
     dotLib[1]=Class.forName("java.lang.Double");
     dotLib[2]=Class.forName("gnu.jel.reflect.Double");
@@ -56,7 +64,7 @@ public class IntegralPrimitiveOPsTest extends TestingUtils {
     vp.addProperty("p1.b1t",VariableProvider.makeJELBooleanObject(true));
     vp.addProperty("p1.b1f",VariableProvider.makeJELBooleanObject(false));
     
-    allowedCasts=new java.util.HashMap<String,Class>();
+    allowedCasts=new java.util.HashMap<String,Class<?>>();
     allowedCasts.put("String",String.class);
     allowedCasts.put("Object",Object.class);
     allowedCasts.put("Double",java.lang.Double.class);
