@@ -33,10 +33,10 @@ public class IntegralVirtualTest extends TestingUtils {
   Object[] rtp;
 
   public void setUp() throws Exception {
-    Class[] dynamicLib=new Class<?>[1];
+    Class<?>[] dynamicLib=new Class<?>[1];
     rtp=new Object[1];
     VariableProvider vp=new VariableProvider();
-    Class[] staticLib=new Class<?>[2];
+    Class<?>[] staticLib=new Class<?>[2];
     staticLib[0]=Class.forName("java.lang.Math");
     // next line makes also static functions from VariablePrivider available
     staticLib[1]=vp.getClass();  
@@ -48,44 +48,44 @@ public class IntegralVirtualTest extends TestingUtils {
   }
   
   public void test1() throws Throwable {
-    simExpression("sin(x/5)",new Double(Math.sin(1.0)),null,rtp,lib,null);
+    simExpression("sin(x/5)",Double.valueOf(Math.sin(1.0)),null,rtp,lib,null);
   }
 
   public void test2() throws Throwable {
-    simExpression("255+5+7+9-x",new Double(255+7+9),null,rtp,lib,null);
+    simExpression("255+5+7+9-x",Double.valueOf(255+7+9),null,rtp,lib,null);
   }
 
   public void test3() throws Throwable {
-    simExpression("-x+255+5+7+9",new Double(255+7+9),null,rtp,lib,null);
+    simExpression("-x+255+5+7+9",Double.valueOf(255+7+9),null,rtp,lib,null);
   }
 
   public void test4() throws Throwable {
-    simExpression("-x+(255+5+7+9)",new Double(255+7+9),null,rtp,lib,null);
+    simExpression("-x+(255+5+7+9)",Double.valueOf(255+7+9),null,rtp,lib,null);
   }
 
   public void test5() throws Throwable {
-    simExpression("5*x-66",new Double(25-66),Double.TYPE,rtp,lib,null);
+    simExpression("5*x-66",Double.valueOf(25-66),Double.TYPE,rtp,lib,null);
   }
 
   public void test6() throws Throwable {
     simExpression("7+(int)4-(int)6.0+(int)x-(int)round((double)((float)((long)x+1)+2)+3)+6",
-                 new Integer(5),null,rtp,lib,null);
+                 Integer.valueOf(5),null,rtp,lib,null);
   }
   
   public void test7() throws Throwable {
-    simExpression("x",new Double(5.0),null,rtp,lib,null);
+    simExpression("x",Double.valueOf(5.0),null,rtp,lib,null);
   }
 
   public void test8() throws Throwable {
-    simExpression("(x)",new Double(5.0),null,rtp,lib,null);
+    simExpression("(x)",Double.valueOf(5.0),null,rtp,lib,null);
   }
 
   public void test9() throws Throwable {
-    simExpression("(-x)",new Double(-5.0),null,rtp,lib,null);
+    simExpression("(-x)",Double.valueOf(-5.0),null,rtp,lib,null);
   }
 
   public void test10() throws Throwable {
-    simExpression("(x())",new Double(5.0),null,rtp,lib,null);
+    simExpression("(x())",Double.valueOf(5.0),null,rtp,lib,null);
   }
   
   public void test11() throws Throwable {
