@@ -22,11 +22,11 @@ package gnu.jel.tests;
 
 public class StringObject implements gnu.jel.reflect.String {
   String val;
-  
+
   public StringObject(String val) {
-	this.val=val;
+    this.val=val;
   };
-  
+
   public int aMethod() {
     return 1;
   };
@@ -36,6 +36,10 @@ public class StringObject implements gnu.jel.reflect.String {
     return val.equals(((StringObject)obj).val);
   };
 
+  public int hashCode() {
+    return val.hashCode();
+  };
+
   public String toString() {
     return val;
   };
